@@ -1,25 +1,19 @@
-from themebase import Theme
-from cyberpunk_theme.widget import toplevel
-from cyberpunk_theme.widget import label
+import tkstyle
+from cyberpunk_theme.widget import label, toplevel
 from cyberpunk_theme import constant
 
 
 # == confirm theme
-def get_theme():
-    theme = Theme()
-    theme.add_style(_get_confirm_toplevel_style(), scope="*Confirm.")
-    theme.add_style(_get_confirm_label_header_style(), scope="*Confirm*label_header*")
-    theme.add_style(_get_confirm_label_message_style(), scope="*Confirm*label_message*")
-    return theme
+def get_style():
+    style = toplevel.get_style()
+    style.add(_get_confirm_label_header_style(), pattern="*label_header")
+    style.add(_get_confirm_label_message_style(), pattern="*label_message")
+    return style
 
 
 # ========================================
 #                PRIVATE
 # ========================================
-# confirm toplevel
-def _get_confirm_toplevel_style():
-    style = toplevel.get_style()
-    return style
 
 
 # confirm header label
