@@ -1,44 +1,37 @@
-import stylebase
-from themebase import Theme
+import tkstyle
 from cyberpunk_theme import constant
 
 
 # == tree theme
-def get_theme():
-    theme = Theme()
-    theme.add_style(_get_tree_body_style(), scope="*Tree.")
-    theme.add_style(_get_tree_node_style(), scope="*Tree*FrameNode.")
-    theme.add_style(_get_tree_header_style(), scope="*Tree*frame_header.")
-    theme.add_style(_get_tree_box_style(), scope="*Tree*frame_box.")
-    return theme
+def get_style():
+    style = tkstyle.Frame()
+    style.background = constant.COLOR_1
+    style.add(_get_tree_node_style(), pattern="*FrameNode")
+    style.add(_get_tree_header_style(), pattern="*frame_header")
+    style.add(_get_tree_box_style(), pattern="*frame_box")
+    return style
 
 
 # ========================================
 #                   PRIVATE
 # ========================================
-# tree body
-def _get_tree_body_style():
-    style = stylebase.Frame()
-    style.background = constant.COLOR_BLACK
-    return style
-
 
 # tree node
 def _get_tree_node_style():
-    style = stylebase.Frame()
+    style = tkstyle.Frame()
     style.background = constant.COLOR_BLACK
     return style
 
 
 # tree header
 def _get_tree_header_style():
-    style = stylebase.Frame()
+    style = tkstyle.Frame()
     style.background = constant.COLOR_BLACK
     return style
 
 
 # tree box
 def _get_tree_box_style():
-    style = stylebase.Frame()
+    style = tkstyle.Frame()
     style.background = constant.COLOR_BLACK
     return style
