@@ -1,13 +1,11 @@
-import stylebase
+import tkstyle
 from cyberpunk_theme import constant
 
 
 def get_style():
-    style = stylebase.Scrollbar()
-    style.activeBackground = constant.COLOR_ALMOST_WHITE
-    style.activeBackground = "#383838"
-    style.background = "gray"
-    style.background = "#282828"
+    style = tkstyle.Scrollbar()
+    style.activeBackground = "#292D31"
+    style.background = "#191D21"
     style.highlightBackground = constant.COLOR_BLACK
     style.highlightColor = constant.COLOR_BLACK
     style.troughColor = constant.COLOR_BLACK
