@@ -1,8 +1,8 @@
-import stylebase
+import tkstyle
 from cyberpunk_theme import constant
 
 
 def get_style():
-    style = stylebase.Toplevel()
+    style = tkstyle.Toplevel()
     style.background = constant.COLOR_BLACK
     return style
